#!/usr/bin/perl
# gallery for https://img.krzysckh.org
#
# krzysckh 2022, 2023
# krzysckh.org

use strict;
use warnings;

use 5.010;
use Time::Piece;
use POSIX qw(tzset);

$ENV{TZ} = 'CET';

my $per_page = 10;
my $name;
my $value;
my $buffer;
my $param;
my @params;
my %INFO;

my $d;
my $img;
my $i = 0;

my $page = 0;

printf "Content-type: text/html\n\n";

printf "<html><head><meta charset=\"utf-8\"><title>img</title>
<link rel=stylesheet href=\"style.css\"></head><body>\n";
print "<table>";

# https://www.tutorialspoint.com/perl/perl_cgi_programming.htm
if ($ENV{'REQUEST_METHOD'}) {
  $ENV{'REQUEST_METHOD'} =~ tr/a-z/A-Z/;
  if ($ENV{'REQUEST_METHOD'} eq "GET") {
     $buffer = $ENV{'QUERY_STRING'};

    @params = split(/&/, $buffer);
    foreach $param (@params) {
      ($name, $value) = split(/=/, $param);
      $value =~ tr/+/ /;
      $value =~ s/%(..)/pack("C", hex($1))/eg;
      $INFO{$name} = $value;
    }
  }

  $page = $INFO{"p"} if ($INFO{"p"});
}
opendir $d, "/var/www/pub/img/" or die "can't get files";
my @f = reverse sort readdir $d;
closedir $d;

my $shown = 0;
my $dontshowme = $page * $per_page;

foreach $img (@f) {
  $dontshowme--;
  next if ($dontshowme > 0);

  next if ($shown == $per_page);
  next if ($img eq "." or $img eq "..");

  my $timestamp = $img;
  $timestamp =~ s/\..*$//;
  printf "<tr><td><img src=\"https://pub.krzysckh.org/img/%s\"></td><td>%s</td></tr>\n",
  $img, scalar localtime $timestamp;
  $shown++;
}

print "</table>";
printf '<a class="d_btn" href="/?p=%d">&lt;</a>', $page-1 if $page;
printf '<a class="d_btn" href="/?p=%d">&gt;</a>', $page+1;
printf '<div id="cc"><pre>all images are under CC BY-SA.</pre>
<a rel="license" href="http://creativecommons.org/licenses/by-sa/2.0/">
<img alt="[cc image]" style="border-width:0" src="https://i.creativecommons.org/l/by-sa/2.0/80x15.png" /></a>
<pre>krzysckh 2022, 2023
krzysckh.org
krzych [at] krzysckh [dot] org
<a id="donate" href="https://liberapay.com/kpm/donate">donate</a></pre></div>';
printf "</body></html>";
